check_day_correctly_entered_ymd: Check if Day Component is Valid in ymd date type

View source: R/impute_date.R

check_day_correctly_entered_ymdR Documentation

Check if Day Component is Valid in ymd date type

Description

This function checks whether the day component in a vector of date strings is valid, i.e., not exceeding the maximum number of days for the given month and year. It returns a logical vector indicating which elements have a correctly specified day.

Usage

check_day_correctly_entered_ymd(data_frame, column_name, separator = "-")

Arguments

data_frame

data frame

column_name

name of column that keeps dates to be imputed

separator

by default "-" it is a day-month-year separator, for example "2024-10-21" has "-" separator

Value

A logical vector

Author(s)

Lukasz Andrzejewski


datetoiso documentation built on Dec. 7, 2025, 9:06 a.m.