| check_if_only_year_entered | R Documentation |
This function determines whether the elements of a vector contain only **year** It returns a logical vector indicating which elements meet this criterion.
check_if_only_year_entered(
data_frame,
column_name,
separator = "-",
month = "UNK",
day = "UN"
)
data_frame |
data frame |
column_name |
name of column that keeps dates to be imputed |
separator |
by default "-" it is a day-month-year separator, for example "2024-10-21" has "-" separator |
month |
by default "UNK" - the format of unknown month |
day |
by default "UN" - the format of unknown day |
A logical vector
Lukasz Andrzejewski
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.