check_if_year_month_entered: Check if a Vector Contains a Year and Month

View source: R/impute_date.R

check_if_year_month_enteredR Documentation

Check if a Vector Contains a Year and Month

Description

This function determines whether the elements of a vector contain a **year** and **month** in the specified order. It returns a logical vector indicating which elements meet this criterion.

Usage

check_if_year_month_entered(data_frame, column_name, separator = "-")

Arguments

data_frame

data frame

column_name

name of column that keeps dates to be imputed

separator

by default "-" it is a day-month-year separator, for example "2024-10-21" has "-" separator

Value

A logical vector

Author(s)

Lukasz Andrzejewski


datetoiso documentation built on Dec. 7, 2025, 9:06 a.m.