Learn R Programming

datetoiso (version 1.2.1)

dfiso: Function recognize date variables and modify them to ISO standard ("International Organization for Standardization")

Description

Function recognize date variables and modify them to ISO standard ("International Organization for Standardization")

Usage

dfiso(df)

Value

dates formatted to ISO standard (yyyy-mm-dd)

Arguments

df

data frame or variable/s, for example data.frame(date=c("12-Mar-2021","01-Jan-2023"))

Author

Lukasz Andrzejewski

Examples

Run this code
# data frame with different formatted dates
dfiso(data.frame(date1=c("13-02-2022","13/Feb/2022","13-Feb-2022")))

Run the code above in your browser using DataLab