Learn R Programming

datetoiso (version 1.2.1)

get_months_sep_by_vertical_bar: Get vector with full and abbreviated name of months separated by vertical bar

Description

Get vector with full and abbreviated name of months separated by vertical bar

Usage

get_months_sep_by_vertical_bar()

Arguments

Value

full names and abbreviations of months separated by vertical bar

Author

Lukasz Andrzejewski