| check_day_correctly_entered_ymd | R Documentation |
This function checks whether the day component in a vector of date strings is valid, i.e., not exceeding the maximum number of days for the given month and year. It returns a logical vector indicating which elements have a correctly specified day.
check_day_correctly_entered_ymd(data_frame, column_name, separator = "-")
data_frame |
data frame |
column_name |
name of column that keeps dates to be imputed |
separator |
by default "-" it is a day-month-year separator, for example "2024-10-21" has "-" separator |
A logical vector
Lukasz Andrzejewski
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.