This function checks whether the day component in a vector of date strings is valid, i.e., not exceeding the maximum number of days for the given month and year. It returns a logical vector indicating which elements have a correctly specified day.
check_day_correctly_entered_ymd(data_frame, column_name, separator = "-")A logical vector
data frame
name of column that keeps dates to be imputed
by default "-" it is a day-month-year separator, for example "2024-10-21" has "-" separator
Lukasz Andrzejewski