Learn R Programming

datetoiso (version 1.2.1)

check_if_month_year_entered: Check if a Vector Contains a Month and Year

Description

This function determines whether the elements of a vector contain a **month** and **year** in the specified order. It returns a logical vector indicating which elements meet this criterion.

Usage

check_if_month_year_entered(data_frame, column_name, separator = "-")

Value

A logical vector

Arguments

data_frame

data frame

column_name

name of column that keeps dates to be imputed

separator

by default "-" it is a day-month-year separator, for example "2024-10-21" has "-" separator