This function determines whether the elements of a vector contain a **month** and **year** in the specified order. It returns a logical vector indicating which elements meet this criterion.
check_if_month_year_entered(data_frame, column_name, separator = "-")A logical vector
data frame
name of column that keeps dates to be imputed
by default "-" it is a day-month-year separator, for example "2024-10-21" has "-" separator