This function determines whether the elements of a vector contain only **year** It returns a logical vector indicating which elements meet this criterion.
check_if_only_year_entered(
data_frame,
column_name,
separator = "-",
month = "UNK",
day = "UN"
)A logical vector
data frame
name of column that keeps dates to be imputed
by default "-" it is a day-month-year separator, for example "2024-10-21" has "-" separator
by default "UNK" - the format of unknown month
by default "UN" - the format of unknown day
Lukasz Andrzejewski